@@ -1,5 +1,5 @@
-#  tests for sympy-1.6-py37hc8dfbb8_0 (this is a generated file);
-print('===== testing package: sympy-1.6-py37hc8dfbb8_0 =====');
+#  tests for sympy-1.6.1-py37hc8dfbb8_0 (this is a generated file);
+print('===== testing package: sympy-1.6.1-py37hc8dfbb8_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import sympy
@@ -10,7 +10,7 @@ a = Rational(14, 4)
 assert str(a) == '7/2'
 #  --- run_test.py (end) ---
 
-print('===== sympy-1.6-py37hc8dfbb8_0 OK =====');
+print('===== sympy-1.6.1-py37hc8dfbb8_0 OK =====');
 print("import: 'sympy'")
 import sympy
 
